@@ -210,6 +210,7 @@ classdefs = {
 ),
 "EssenceDescriptor"     : ("0d010101-0101-2400-060e-2b3402060101", "0d010101-0101-0100-060e-2b3402060101", False, {
     "Locator"               : ("06010104-0603-0000-060e-2b3401010102", 0x2f01, "05060400-0000-0000-060e-2b3401040101", True, False),
+    "SubDescriptors"        : ("06010104-0610-0000-060e-2b3401010109", None, "05060e00-0000-0000-060e-2b3401040101", True, False),
     }
 ),
 "FileDescriptor"        : ("0d010101-0101-2500-060e-2b3402060101", "0d010101-0101-2400-060e-2b3402060101", False, {
@@ -323,6 +324,7 @@ classdefs = {
     "Version"               : ("03010201-0500-0000-060e-2b3401010102", 0x3b05, "03010300-0000-0000-060e-2b3401040101", False, False),
     "IdentificationList"    : ("06010104-0604-0000-060e-2b3401010102", 0x3b06, "05060300-0000-0000-060e-2b3401040101", False, False),
     "ObjectModelVersion"    : ("03010201-0400-0000-060e-2b3401010102", 0x3b07, "01010300-0000-0000-060e-2b3401040101", True, False),
+    "PrimaryMob"            : ("06010104-0108-0000-060e-2b3401010104", 0x3b08, "05010600-0000-0000-060e-2b3401040101", True, False),
     "OperationalPattern"    : ("01020203-0000-0000-060e-2b3401010105", 0x3b09, "01030100-0000-0000-060e-2b3401040101", True, False),
     "EssenceContainers"     : ("01020210-0201-0000-060e-2b3401010105", 0x3b0a, "04030100-0000-0000-060e-2b3401040101", True, False),
     "DescriptiveSchemes"    : ("01020210-0202-0000-060e-2b3401010105", 0x3b0b, "04030100-0000-0000-060e-2b3401040101", True, False),
@@ -450,6 +452,16 @@ classdefs = {
     "DescribedSlotIDs"      : ("01070106-0000-0000-060e-2b3401010105", 0x6103, "04030200-0000-0000-060e-2b3401040101", True, False),
     }
 ),
+"AES3PCMDescriptor"     : ("0d010101-0101-4700-060e-2b3402060101", "0d010101-0101-4800-060e-2b3402060101", True, {
+    "Emphasis"              : ("04020501-0600-0000-060e-2b3401010105", 0x3d0d, "02010123-0000-0000-060e-2b3401040101", True, False),
+    "BlockStartOffset"      : ("04020302-0300-0000-060e-2b3401010105", 0x3d0f, "01010200-0000-0000-060e-2b3401040101", True, False),
+    "AuxBitsMode"           : ("04020501-0100-0000-060e-2b3401010105", 0x3d08, "02010124-0000-0000-060e-2b3401040101", True, False),
+    "ChannelStatusMode"     : ("04020501-0200-0000-060e-2b3401010105", 0x3d10, "04010a00-0000-0000-060e-2b3401040101", True, False),
+    "FixedChannelStatusData": ("04020501-0300-0000-060e-2b3401010105", 0x3d11, "04010100-0000-0000-060e-2b3401040101", True, False),
+    "UserDataMode"          : ("04020501-0400-0000-060e-2b3401010105", 0x3d12, "04010b00-0000-0000-060e-2b3401040101", True, False),
+    "FixedUserData"         : ("04020501-0500-0000-060e-2b3401010105", 0x3d13, "04010100-0000-0000-060e-2b3401040101", True, False),
+    }
+),
 "PCMDescriptor"         : ("0d010101-0101-4800-060e-2b3402060101", "0d010101-0101-4200-060e-2b3402060101", True, {
     "BlockAlign"            : ("04020302-0100-0000-060e-2b3401010105", 0x3d0a, "01010200-0000-0000-060e-2b3401040101", False, False),
     "SequenceOffset"        : ("04020302-0200-0000-060e-2b3401010105", 0x3d0b, "01010100-0000-0000-060e-2b3401040101", True, False),
@@ -466,16 +478,6 @@ classdefs = {
     "PeakEnvelopeData"      : ("04020301-0e00-0000-060e-2b3401010108", 0x3d31, "04100200-0000-0000-060e-2b3401040101", True, False),
     }
 ),
-"AES3PCMDescriptor"     : ("0d010101-0101-4700-060e-2b3402060101", "0d010101-0101-4800-060e-2b3402060101", True, {
-    "Emphasis"              : ("04020501-0600-0000-060e-2b3401010105", 0x3d0d, "02010123-0000-0000-060e-2b3401040101", True, False),
-    "BlockStartOffset"      : ("04020302-0300-0000-060e-2b3401010105", 0x3d0f, "01010200-0000-0000-060e-2b3401040101", True, False),
-    "AuxBitsMode"           : ("04020501-0100-0000-060e-2b3401010105", 0x3d08, "02010124-0000-0000-060e-2b3401040101", True, False),
-    "ChannelStatusMode"     : ("04020501-0200-0000-060e-2b3401010105", 0x3d10, "04010a00-0000-0000-060e-2b3401040101", True, False),
-    "FixedChannelStatusData": ("04020501-0300-0000-060e-2b3401010105", 0x3d11, "04010100-0000-0000-060e-2b3401040101", True, False),
-    "UserDataMode"          : ("04020501-0400-0000-060e-2b3401010105", 0x3d12, "04010b00-0000-0000-060e-2b3401040101", True, False),
-    "FixedUserData"         : ("04020501-0500-0000-060e-2b3401010105", 0x3d13, "04010100-0000-0000-060e-2b3401040101", True, False),
-    }
-),
 "PhysicalDescriptor"    : ("0d010101-0101-4900-060e-2b3402060101", "0d010101-0101-2400-060e-2b3402060101", False, {
     }
 ),
@@ -518,22 +520,16 @@ classdefs = {
     }
 ),
 "MPEGVideoDescriptor"   : ("0d010101-0101-5100-060e-2b3402060101", "0d010101-0101-2800-060e-2b3402060101", True, {
-    "SingleSequence"        : ("04010602-0102-0000-060e-2b3401010105", 0xffff, "01040100-0000-0000-060e-2b3401040101", True, False),
-    "ConstantBPictureCount" : ("04010602-0103-0000-060e-2b3401010105", 0xfffe, "01040100-0000-0000-060e-2b3401040101", True, False),
-    "CodedContentScanning"  : ("04010602-0104-0000-060e-2b3401010105", 0xfffd, "0201012a-0000-0000-060e-2b3401040101", True, False),
-    "LowDelay"              : ("04010602-0105-0000-060e-2b3401010105", 0xfffc, "01040100-0000-0000-060e-2b3401040101", True, False),
-    "ClosedGOP"             : ("04010602-0106-0000-060e-2b3401010105", 0xfffb, "01040100-0000-0000-060e-2b3401040101", True, False),
-    "IdenticalGOP"          : ("04010602-0107-0000-060e-2b3401010105", 0xfffa, "01040100-0000-0000-060e-2b3401040101", True, False),
-    "MaxGOP"                : ("04010602-0108-0000-060e-2b3401010105", 0xfff9, "01010200-0000-0000-060e-2b3401040101", True, False),
-    "MaxBPictureCount"      : ("04010602-0109-0000-060e-2b3401010105", 0xfff8, "01010200-0000-0000-060e-2b3401040101", True, False),
-    "BitRate"               : ("04010602-010b-0000-060e-2b3401010105", 0xfff7, "01010300-0000-0000-060e-2b3401040101", True, False),
-    "ProfileAndLevel"       : ("04010602-010a-0000-060e-2b3401010105", 0xfff6, "01010100-0000-0000-060e-2b3401040101", True, False),
-    }
-),
-"MetaDefinition"        : ("0d010101-0224-0000-060e-2b3402060101", None, False, {
-    "Identification"        : ("06010107-1300-0000-060e-2b3401010102", 0x0005, "01030100-0000-0000-060e-2b3401040101", False, True),
-    "Name"                  : ("03020401-0201-0000-060e-2b3401010102", 0x0006, "01100200-0000-0000-060e-2b3401040101", False, False),
-    "Description"           : ("06010107-1401-0000-060e-2b3401010102", 0x0007, "01100200-0000-0000-060e-2b3401040101", True, False),
+    "SingleSequence"        : ("04010602-0102-0000-060e-2b3401010105", None, "01040100-0000-0000-060e-2b3401040101", True, False),
+    "ConstantBPictureCount" : ("04010602-0103-0000-060e-2b3401010105", None, "01040100-0000-0000-060e-2b3401040101", True, False),
+    "CodedContentScanning"  : ("04010602-0104-0000-060e-2b3401010105", None, "0201012a-0000-0000-060e-2b3401040101", True, False),
+    "LowDelay"              : ("04010602-0105-0000-060e-2b3401010105", None, "01040100-0000-0000-060e-2b3401040101", True, False),
+    "ClosedGOP"             : ("04010602-0106-0000-060e-2b3401010105", None, "01040100-0000-0000-060e-2b3401040101", True, False),
+    "IdenticalGOP"          : ("04010602-0107-0000-060e-2b3401010105", None, "01040100-0000-0000-060e-2b3401040101", True, False),
+    "MaxGOP"                : ("04010602-0108-0000-060e-2b3401010105", None, "01010200-0000-0000-060e-2b3401040101", True, False),
+    "MaxBPictureCount"      : ("04010602-0109-0000-060e-2b3401010105", None, "01010200-0000-0000-060e-2b3401040101", True, False),
+    "BitRate"               : ("04010602-010b-0000-060e-2b3401010105", None, "01010300-0000-0000-060e-2b3401040101", True, False),
+    "ProfileAndLevel"       : ("04010602-010a-0000-060e-2b3401010105", None, "01010100-0000-0000-060e-2b3401040101", True, False),
     }
 ),
 "ClassDefinition"       : ("0d010101-0201-0000-060e-2b3402060101", "0d010101-0224-0000-060e-2b3402060101", True, {
@@ -572,6 +568,98 @@ classdefs = {
     "ElementValues"         : ("03010203-0500-0000-060e-2b3401010102", 0x0016, "04010400-0000-0000-060e-2b3401040101", False, False),
     }
 ),
+"SubDescriptor"         : ("0d010101-0101-5900-060e-2b3402060101", "0d010101-0101-0100-060e-2b3402060101", False, {
+    }
+),
+"JPEG2000SubDescriptor" : ("0d010101-0101-5a00-060e-2b3402060101", "0d010101-0101-5900-060e-2b3402060101", True, {
+    "Rsiz"                  : ("04010603-0100-0000-060e-2b340101010a", None, "01010200-0000-0000-060e-2b3401040101", False, False),
+    "Xsiz"                  : ("04010603-0200-0000-060e-2b340101010a", None, "01010300-0000-0000-060e-2b3401040101", False, False),
+    "Ysiz"                  : ("04010603-0300-0000-060e-2b340101010a", None, "01010300-0000-0000-060e-2b3401040101", False, False),
+    "XOsiz"                 : ("04010603-0400-0000-060e-2b340101010a", None, "01010300-0000-0000-060e-2b3401040101", False, False),
+    "YOsiz"                 : ("04010603-0500-0000-060e-2b340101010a", None, "01010300-0000-0000-060e-2b3401040101", False, False),
+    "XTsiz"                 : ("04010603-0600-0000-060e-2b340101010a", None, "01010300-0000-0000-060e-2b3401040101", False, False),
+    "YTsiz"                 : ("04010603-0700-0000-060e-2b340101010a", None, "01010300-0000-0000-060e-2b3401040101", False, False),
+    "XTOsiz"                : ("04010603-0800-0000-060e-2b340101010a", None, "01010300-0000-0000-060e-2b3401040101", False, False),
+    "YTOsiz"                : ("04010603-0900-0000-060e-2b340101010a", None, "01010300-0000-0000-060e-2b3401040101", False, False),
+    "Csiz"                  : ("04010603-0a00-0000-060e-2b340101010a", None, "01010200-0000-0000-060e-2b3401040101", False, False),
+    "PictureComponentSizing": ("04010603-0b00-0000-060e-2b340101010a", None, "04010100-0000-0000-060e-2b3401040101", False, False),
+    "CodingStyleDefault"    : ("04010603-0c00-0000-060e-2b340101010a", None, "04100100-0000-0000-060e-2b3401040101", True, False),
+    "QuantizationDefault"   : ("04010603-0d00-0000-060e-2b340101010a", None, "04100100-0000-0000-060e-2b3401040101", True, False),
+    "J2CLayout"             : ("04010603-0e00-0000-060e-2b340101010e", None, "04020100-0000-0000-060e-2b3401040101", True, False),
+    }
+),
+"VBIDataDescriptor"     : ("0d010101-0101-5b00-060e-2b3402060101", "0d010101-0101-4300-060e-2b3402060101", True, {
+    }
+),
+"ANCDataDescriptor"     : ("0d010101-0101-5c00-060e-2b3402060101", "0d010101-0101-4300-060e-2b3402060101", True, {
+    }
+),
+"ContainerConstraintsSubDescriptor" : ("0d010101-0101-6700-060e-2b3402060101", "0d010101-0101-5900-060e-2b3402060101", True, {
+    }
+),
+"MPEG4VisualSubDescriptor" : ("0d010101-0101-6800-060e-2b3402060101", "0d010101-0101-5900-060e-2b3402060101", True, {
+    "MPEG4VisualSingleSequence": ("04010602-0202-0000-060e-2b340101010d", None, "01040100-0000-0000-060e-2b3401040101", True, False),
+    "MPEG4VisualConstantBVOPs": ("04010602-0203-0000-060e-2b340101010d", None, "01040100-0000-0000-060e-2b3401040101", True, False),
+    "MPEG4VisualCodedContentType": ("04010602-0204-0000-060e-2b340101010d", None, "0201012d-0000-0000-060e-2b3401040101", True, False),
+    "MPEG4VisualLowDelay"   : ("04010602-0205-0000-060e-2b340101010d", None, "01040100-0000-0000-060e-2b3401040101", True, False),
+    "MPEG4VisualClosedGOV"  : ("04010602-0206-0000-060e-2b340101010d", None, "01040100-0000-0000-060e-2b3401040101", True, False),
+    "MPEG4VisualIdenticalGOV": ("04010602-0207-0000-060e-2b340101010d", None, "01040100-0000-0000-060e-2b3401040101", True, False),
+    "MPEG4VisualMaxGOV"     : ("04010602-0208-0000-060e-2b340101010d", None, "01010200-0000-0000-060e-2b3401040101", True, False),
+    "MPEG4VisualBVOPCount"  : ("04010602-0209-0000-060e-2b340101010d", None, "01010200-0000-0000-060e-2b3401040101", True, False),
+    "MPEG4VisualProfileAndLevel": ("04010602-020a-0000-060e-2b340101010d", None, "01010100-0000-0000-060e-2b3401040101", True, False),
+    "MPEG4VisualBitRate"    : ("04010602-020b-0000-060e-2b340101010d", None, "01010300-0000-0000-060e-2b3401040101", True, False),
+    }
+),
+"MCALabelSubDescriptor" : ("0d010101-0101-6a00-060e-2b3402060101", "0d010101-0101-5900-060e-2b3402060101", False, {
+    "MCALabelDictionaryID"  : ("01030701-0100-0000-060e-2b340101010e", None, "01030100-0000-0000-060e-2b3401040101", False, False),
+    "MCALinkID"             : ("01030701-0500-0000-060e-2b340101010e", None, "01030300-0000-0000-060e-2b3401040101", False, False),
+    "MCATagSymbol"          : ("01030701-0200-0000-060e-2b340101010e", None, "01100200-0000-0000-060e-2b3401040101", False, False),
+    "MCATagName"            : ("01030701-0300-0000-060e-2b340101010e", None, "01100200-0000-0000-060e-2b3401040101", True, False),
+    "MCAChannelID"          : ("0103040a-0000-0000-060e-2b340101010e", None, "01010300-0000-0000-060e-2b3401040101", True, False),
+    "RFC5646SpokenLanguage" : ("03010102-0315-0000-060e-2b340101010d", None, "01100400-0000-0000-060e-2b3401040101", True, False),
+    "MCATitle"              : ("01051000-0000-0000-060e-2b340101010e", None, "01100200-0000-0000-060e-2b3401040101", True, False),
+    "MCATitleVersion"       : ("01051100-0000-0000-060e-2b340101010e", None, "01100200-0000-0000-060e-2b3401040101", True, False),
+    "MCATitleSubVersion"    : ("01051200-0000-0000-060e-2b340101010e", None, "01100200-0000-0000-060e-2b3401040101", True, False),
+    "MCAEpisode"            : ("01051300-0000-0000-060e-2b340101010e", None, "01100200-0000-0000-060e-2b3401040101", True, False),
+    "MCAPartitionKind"      : ("01040105-0000-0000-060e-2b340101010e", None, "01100200-0000-0000-060e-2b3401040101", True, False),
+    "MCAPartitionNumber"    : ("01040106-0000-0000-060e-2b340101010e", None, "01100200-0000-0000-060e-2b3401040101", True, False),
+    "MCAAudioContentKind"   : ("03020102-2000-0000-060e-2b340101010e", None, "01100200-0000-0000-060e-2b3401040101", True, False),
+    "MCAAudioElementKind"   : ("03020102-2100-0000-060e-2b340101010e", None, "01100200-0000-0000-060e-2b3401040101", True, False),
+    }
+),
+"AudioChannelLabelSubDescriptor" : ("0d010101-0101-6b00-060e-2b3402060101", "0d010101-0101-6a00-060e-2b3402060101", True, {
+    "SoundfieldGroupLinkID" : ("01030701-0600-0000-060e-2b340101010e", None, "01030300-0000-0000-060e-2b3401040101", True, False),
+    }
+),
+"SoundfieldGroupLabelSubDescriptor" : ("0d010101-0101-6c00-060e-2b3402060101", "0d010101-0101-6a00-060e-2b3402060101", True, {
+    "GroupOfSoundfieldGroupsLinkID": ("01030701-0400-0000-060e-2b340101010e", None, "04011500-0000-0000-060e-2b3401040101", True, False),
+    }
+),
+"GroupOfSoundfieldGroupsLabelSubDescriptor" : ("0d010101-0101-6d00-060e-2b3402060101", "0d010101-0101-6a00-060e-2b3402060101", True, {
+    }
+),
+"AVCSubDescriptor"      : ("0d010101-0101-6e00-060e-2b3402060101", "0d010101-0101-5900-060e-2b3402060101", True, {
+    "AVCConstantBPictureFlag": ("04010606-0103-0000-060e-2b340101010e", None, "01040100-0000-0000-060e-2b3401040101", True, False),
+    "AVCCodedContentKind"   : ("04010606-0104-0000-060e-2b340101010e", None, "0201012c-0000-0000-060e-2b3401040101", True, False),
+    "AVCClosedGOPIndicator" : ("04010606-0106-0000-060e-2b340101010e", None, "01040100-0000-0000-060e-2b3401040101", True, False),
+    "AVCIdenticalGOPIndicator": ("04010606-0107-0000-060e-2b340101010e", None, "01040100-0000-0000-060e-2b3401040101", True, False),
+    "AVCMaximumGOPSize"     : ("04010606-0108-0000-060e-2b340101010e", None, "01010200-0000-0000-060e-2b3401040101", True, False),
+    "AVCMaximumBPictureCount": ("04010606-0109-0000-060e-2b340101010e", None, "01010200-0000-0000-060e-2b3401040101", True, False),
+    "AVCProfile"            : ("04010606-010a-0000-060e-2b340101010e", None, "01010100-0000-0000-060e-2b3401040101", True, False),
+    "AVCMaximumBitRate"     : ("04010606-010b-0000-060e-2b340101010e", None, "01010300-0000-0000-060e-2b3401040101", True, False),
+    "AVCProfileConstraint"  : ("04010606-010c-0000-060e-2b340101010e", None, "01010100-0000-0000-060e-2b3401040101", True, False),
+    "AVCLevel"              : ("04010606-010d-0000-060e-2b340101010e", None, "01010100-0000-0000-060e-2b3401040101", True, False),
+    "AVCDecodingDelay"      : ("04010606-010e-0000-060e-2b340101010e", None, "01010100-0000-0000-060e-2b3401040101", False, False),
+    "AVCMaximumRefFrames"   : ("04010606-010f-0000-060e-2b340101010e", None, "01010100-0000-0000-060e-2b3401040101", True, False),
+    "AVCSequenceParameterSetFlag": ("04010606-0110-0000-060e-2b340101010e", None, "01010100-0000-0000-060e-2b3401040101", True, False),
+    "AVCPictureParameterSetFlag": ("04010606-0111-0000-060e-2b340101010e", None, "01010100-0000-0000-060e-2b3401040101", True, False),
+    "AVCAverageBitRate"     : ("04010606-0114-0000-060e-2b340101010e", None, "01010300-0000-0000-060e-2b3401040101", True, False),
+    }
+),
+"MPEGAudioDescriptor"   : ("0d010101-0101-5e00-060e-2b3402060101", "0d010101-0101-4200-060e-2b3402060101", True, {
+    "MPEGAudioBitRate"      : ("04020403-0102-0000-060e-2b340101010a", None, "01010300-0000-0000-060e-2b3401040101", True, False),
+    }
+),
 "TypeDefinitionFixedArray" : ("0d010101-0208-0000-060e-2b3402060101", "0d010101-0203-0000-060e-2b3402060101", True, {
     "ElementType"           : ("06010107-0c00-0000-060e-2b3401010102", 0x0017, "05010900-0000-0000-060e-2b3401040101", False, False),
     "ElementCount"          : ("03010203-0300-0000-060e-2b3401010102", 0x0018, "01010300-0000-0000-060e-2b3401040101", False, False),
@@ -615,6 +703,16 @@ classdefs = {
 "TypeDefinitionCharacter" : ("0d010101-0223-0000-060e-2b3402060101", "0d010101-0203-0000-060e-2b3402060101", True, {
     }
 ),
+"TypeDefinitionGenericCharacter" : ("0e040101-0000-0000-060e-2b3402060101", "0d010101-0203-0000-060e-2b3402060101", True, {
+    "CharacterSize"         : ("0e040101-0101-0111-060e-2b3401010101", None, "01010100-0000-0000-060e-2b3401040101", False, False),
+    }
+),
+"MetaDefinition"        : ("0d010101-0224-0000-060e-2b3402060101", None, False, {
+    "Identification"        : ("06010107-1300-0000-060e-2b3401010102", 0x0005, "01030100-0000-0000-060e-2b3401040101", False, True),
+    "Name"                  : ("03020401-0201-0000-060e-2b3401010102", 0x0006, "01100200-0000-0000-060e-2b3401040101", False, False),
+    "Description"           : ("06010107-1401-0000-060e-2b3401010102", 0x0007, "01100200-0000-0000-060e-2b3401040101", True, False),
+    }
+),
 "MetaDictionary"        : ("0d010101-0225-0000-060e-2b3402060101", None, True, {
     "ClassDefinitions"      : ("06010107-0700-0000-060e-2b3401010102", 0x0003, "05050100-0000-0000-060e-2b3401040101", True, False),
     "TypeDefinitions"       : ("06010107-0800-0000-060e-2b3401010102", 0x0004, "05050c00-0000-0000-060e-2b3401040101", True, False),
@@ -637,7 +735,6 @@ aliases = {
 "Object"                 : "InterchangeObject",
 "ParameterDef"           : "ParameterDefinition",
 "InterpolationDef"       : "InterpolationDefinition",
-"TaggedValueDef"         : "TaggedValueDefinition",
 "PropertyDef"            : "PropertyDefinition",
 "TypeDef"                : "TypeDefinition",
 "TypeDefCharacter"       : "TypeDefinitionCharacter",
@@ -657,4 +754,7 @@ aliases = {
 "TypeDefWeakObjRef"      : "TypeDefinitionWeakObjectReference",
 "ContainerDef"           : "ContainerDefinition",
 "PluginDef"              : "PluginDefinition",
+"AvidTypeDefinitionGenericCharacter" : "TypeDefinitionGenericCharacter",
+"TaggedValueDef"         : "TaggedValueDefinition",
+"TypeDefGenericCharacter": "TypeDefinitionGenericCharacter",
 }
